Swimbundle Utils
==================

Python package repo for Swimlane Utils

See Quickstart: https://github.com/swimlane/swimbundle-utils/wiki/Quickstart


.. list-table:: Included Utilities
   :widths: 20 80
   :header-rows: 1

   * - Name
     - Description
   * - flattener
     - flatten json dicts and lists, with other useful dict-related functions
   * - rest
     - basic rest api mixin, pagination support, and other common rest functions
   * - exceptions
     - Useful common exceptions for Swimlane Bundles
   * - helpers
     - Helper funcs for making code for Swimbundles, includes validation
   * - validation
     - More advanced tools for validating inputs
   * - ioc
     - Parse IOCs out of text and determine the type of an IOC

Compatibility:
  * swimlane >= 10.2.0